function love.load()

  worldHeight = 800
  worldWidth = 1024
  world = love.physics.newWorld(0, 0, worldWidth, worldHeight) --create a world for the bodies to exist in with width and height
  world:setGravity(0, 50) --the x component of the gravity will be 0, and the y component of the gravity will be 80
  world:setMeter(64) --the height of a meter in this world will be 64px
  love.mouse.setGrab(true)
 
  objects = {} -- table to hold all our physical objects
  
  bodyX = 0
  bodyY = 0
  maxSpeed = 400
  numChains = 12
  chainCategory = 2
 
  --create objects
  
  --walls
  objects.walls = {}
  objects.ground = {}
  objects.leftwall = {}
  objects.rightwall = {}
  objects.ceiling = {}
  
  --we need to give the ground a mass of zero so that the ground wont move
  objects.walls.body = love.physics.newBody(world, worldWidth/2, worldHeight/2, 0, 0) --remember, the body anchors from the center of the shape
  
  objects.rightwall.shape = love.physics.newRectangleShape(objects.walls.body, worldWidth/2, 0, 50, worldHeight, 0)
  objects.leftwall.shape = love.physics.newRectangleShape(objects.walls.body, -worldWidth/2, 0, 50, worldHeight, 0)
  objects.ceiling.shape = love.physics.newRectangleShape(objects.walls.body, 0, -worldHeight/2, worldWidth, 50, 0)
  objects.ground.shape = love.physics.newRectangleShape(objects.walls.body, 0, worldHeight/2, worldWidth, 50, 0) --anchor the shape to the body, and make it a width of 800 and a height of 50
  
  --let's create a ball
  objects.ball = {}
  objects.ball.body = love.physics.newBody(world, worldWidth/2, worldHeight/2, 1e5, 0) --place the body in the center of the world, with a mass of 15
  objects.ball.shape = love.physics.newCircleShape(objects.ball.body, 0, 0, 20) --the ball's shape has no offset from it's body and has a radius of 20
  
  objects.ball.body:setLinearDamping(.1)
  
	objects.sword = {}
	objects.sword.body = love.physics.newBody(world, worldWidth/2+100, worldHeight/2, 60, 100)
	--objects.sword.shape = love.physics.newPolygonShape(objects.sword.body, -100, -10, -100, 10, 0, 0)
	objects.sword.shape = love.physics.newRectangleShape(objects.sword.body, -50, 0, 100, 10, 0)
	
	objects.ball.body:setLinearDamping(.15)

	objects.ballswordjoint = {}
	objects.ballswordjoint.joint = love.physics.newRevoluteJoint(objects.ball.body, objects.sword.body, worldWidth/2, worldHeight/2)
	--objects.ballswordjoint.joint:setCollideConnected(false)
	
	objects.sword.body:setAngularDamping(.1)

	--Make some boxes to throw around
	objects.boxes = {}
	boxW = 5
	boxH = 5
	numW = 21
	numH = 21
	--makeBoxes(numW, numH, boxW, boxH, 0, 750, objects.boxes)
	makeBoxes(numW, numH, boxW, boxH, 100, 750, .1, .1, objects.boxes)
	


	--initial graphics setup
	love.graphics.setBackgroundColor(104, 136, 248) --set the background color to a nice blue
	love.graphics.setMode(worldWidth, worldHeight, false, true, 0) --set the window dimensions to 800 by 800
end


function love.update(dt)
	world:update(dt) --this puts the world into motion

	x, y = love.mouse.getPosition()

	bodyX, bodyY = objects.ball.body:getPosition()


	local relPosX = x - bodyX
	local relPosY = y - bodyY
	local diff = math.sqrt(relPosX*relPosX+relPosY*relPosY)

	local theta = math.atan2(relPosY, relPosX)
		moveSpeed = math.sqrt(4*relPosX*relPosX + 4*relPosY*relPosY)
	if moveSpeed > maxSpeed then
	moveSpeed = maxSpeed
	end

	if love.mouse.isDown("l") then
	objects.ball.body:setLinearVelocity(moveSpeed*math.cos(theta), moveSpeed*math.sin(theta))
	end
end

function love.draw()
	love.graphics.setColor(72, 160, 14) -- set the drawing color to green for the ground
	love.graphics.polygon("fill", objects.ground.shape:getPoints()) -- draw a "filled in" polygon using the ground's coordinates
	love.graphics.polygon("fill", objects.ceiling.shape:getPoints())
	love.graphics.polygon("fill", objects.leftwall.shape:getPoints())
	love.graphics.polygon("fill", objects.rightwall.shape:getPoints())
	

	love.graphics.setColor(250, 250, 250)
	love.graphics.polygon("fill", objects.sword.shape:getPoints())

	love.graphics.setColor(193, 47, 14) --set the drawing color to red for the ball
	love.graphics.circle("fill", objects.ball.body:getX(), objects.ball.body:getY(), objects.ball.shape:getRadius(), 20) -- we want 20 line segments to form the "circle"


	love.graphics.setColor(200, 200, 200)

	--Draw boxes
	for i=1, numW do
		for j=1, numH do
			love.graphics.polygon("fill", objects.boxes[i][j].shape:getPoints())
		end
	end
end

function makeBoxes(w, h, boxW, boxH, left, bot, mass, rotIner, boxes)
	for i=1, w do
		boxes[i] = {}
		for j=1, h do
			boxes[i][j] = {}
			boxes[i][j].body = love.physics.newBody(world, left + i*boxW, bot - i*boxH, mass, rotIner)
			boxes[i][j].shape = love.physics.newRectangleShape(objects.boxes[i][j].body, 0, 0, boxW, boxH, 0)
		end
	end
end
	